pub fn extract_frontmatter(markdown: &str) -> MdResult<ExtractedFrontmatter<'_>>Expand description
Extracts YAML frontmatter from a markdown string.
Recognizes a frontmatter block only when the very first line is ---.
The block ends at the first line that is exactly --- or ....